==> yaml_collection_03_12_2025-17_32.zip: themes/artwork_v2/snippets/display_item_mosaique.php <==
<?php
if($item->get('intercalaire')=="true"){
?>
<article data-source="<?= $item->filename ?>" class="item intercalaire border-bottom mt-5" 
         <?php
         if(isadmin()){
             echo "onclick=\"yc_editItem('".$item->filename."')\"";
             
         }
         ?> >
    <div class="intercalaire-titre text-maj ff-bold-secondary fs-medium" data-contenu='titre'>
        <?= $item->get('titre') ?>
    </div>
    <?php      
    if($item->get('texte',false)){
        echo "<div class=\"intercalaire-texte fs-small pb-1\">";
        echo $item->get('texte'); 
        echo "</div>";
    }
    ?>
</article>
<?php
                                      } else {
?>
<article class="item" data-source="<?= $item->filename ?>" onclick="yc_clicItem(this)" data-id="<?= isset($num) ? sprintf("%'.06d", $num) : 100000 ?>" data-date="<?= $item->get('date_creation',date('Y-m-d')) ?>">
    <div class="item-grid">
        <div><img src="app/images/defaut.jpg" data-source="<?php
    $im=new thumbnail_tool(CHEMIN,CACHE_VIGNETTES,APP."images/");
                                              $im->set_source(IMPORTS.$item->getFile('illustration'));
                                              echo $im->vignette(VIGNETTE_W,VIGNETTE_H,true); ?>" class="item-illu img-object-fit"></div>
        <div class="item-cartouche">
            <h2 data-contenu='titre' class="fs-medium ff-bold-primary mb-1"><?= $item->get('titre') ?></h2>

            <div class="item-info ff-bold-secondary item-techspecs mb-1" data-contenu="techspecs"><span data-contenu="techspecs"><?= $item->get("techspecs") ?></span> —&nbsp;<span data-contenu="date_oeuvre"><?= formate_date($item->get("date_oeuvre"),"year") ?></span></div>

            <div class="fs-small ff-bold-secondary item-infos mt-3">
                <span class="item-medium" data-contenu="medium"><?= $item->getPropre("medium") ?></span>  
            </div>
        </div>
    </div>
</article> 
<?php
                                             }
?>

==> yaml_collection_12_11_2025-19_14.zip: themes/artwork_v2/snippets/display_item_mosaique.php <==
<?php
if($item->get('intercalaire')=="true"){
?>
<article class="item intercalaire border-bottom mt-5" data-source="<?= $item->filename ?>" onclick="yc_clicItem(this)">
    <div class="intercalaire-titre text-maj ff-bold-secondary fs-medium" data-contenu='titre'>
        <?= $item->get('titre') ?>
    </div>
    <?php      
    if($item->get('texte',false)){
        echo "<div class=\"intercalaire-texte fs-small pb-1\">";
        echo $item->get('texte'); 
        echo "</div>";
    }
    ?>
</article>
<?php
                                      } else {
?>
<article class="item" data-source="<?= $item->filename ?>" onclick="yc_clicItem(this)" data-id="<?= isset($num) ? sprintf("%'.06d", $num) : 100000 ?>" data-date="<?= $item->get('date_creation',date('Y-m-d')) ?>">
    <div class="item-grid">
        <div><img src="app/images/defaut.jpg" data-source="<?php
    $im=new thumbnail_tool(CHEMIN,CACHE_VIGNETTES,APP."images/");
                                              $im->set_source(IMPORTS.$item->getFile('illustration'));
                                              echo $im->vignette(VIGNETTE_W,VIGNETTE_H,true); ?>" class="item-illu img-object-fit"></div>
        <div class="item-cartouche">
            <h2 data-contenu='titre' class="fs-medium ff-bold-primary mb-1"><?= $item->get('titre') ?></h2>

            <div class="item-info ff-bold-secondary item-techspecs mb-1" data-contenu="techspecs"><span data-contenu="techspecs"><?= $item->get("techspecs") ?></span> —&nbsp;<span data-contenu="date_oeuvre"><?= formate_date($item->get("date_oeuvre"),"year") ?></span></div>


            <div class="item-description">
                <?= $item->getTextPart("texte",300) ?>
            </div>

            <div class="fs-small ff-bold-secondary item-infos mt-3">
                <span class="item-medium" data-contenu="medium"><?= $item->getPropre("medium") ?></span>  
            </div>
        </div>
    </div>
</article> 
<?php
                                             }
?>
